@@ -1,4 +1,4 @@
-from typing import Dict, Generator, List, Union
+from typing import Dict, List, Union
 
 from belvo.resources.base import Resource
 
@@ -27,12 +27,3 @@ class Incomes(Resource):
         return self.session.post(
             self.endpoint, data=data, raise_exception=raise_exception, **kwargs
         )
-
-    def list(self, **kwargs) -> Generator:
-        raise NotImplementedError()
-
-    def get(self, id: str, **kwargs) -> Dict:
-        raise NotImplementedError()
-
-    def delete(self, id: str) -> bool:
-        raise NotImplementedError()
